==> qtmobilehotspot_0.3.3.tar.gz: qtmobilehotspot-0.3.3/qtMobileHotspot/src/accesspointgui.cpp <==
#include <QtGui/QDialog>
#include <QtGui/QMessageBox>
#include <QtCore/QString>
#include "mobilehotspotconfiguration.h"
#include "accesspointgui.h"


AccessPointGUI::AccessPointGUI(QWidget *parent)
    : QDialog(parent)
{
	ui.setupUi(this);
}

AccessPointGUI::~AccessPointGUI()
{

}

void AccessPointGUI::setConfiguration(MobileHotspotConfiguration &configuration){
	ui.txtAPName->setText(configuration.hotspotName);
	ui.chkEncryption->setChecked(configuration.encryptionType == configuration.ENCRYPTION_WEP);
	ui.txtKey->setText(configuration.encryptionKey);
	ui.chkWLANDriver->setChecked(configuration.cycleWlanDriver);
}

void AccessPointGUI::configuration(MobileHotspotConfiguration *configuration){
	QString name = ui.txtAPName->text().replace("\\", "").replace("\"", "");
	configuration->hotspotName = name == "" ? "N900 Hotspot" : name;
	configuration->encryptionType = ui.chkEncryption->isChecked() ? configuration->ENCRYPTION_WEP : configuration->ENCRYPTION_NONE;
	configuration->encryptionKey = validKey();
	configuration->cycleWlanDriver = ui.chkWLANDriver->isChecked();
}

QString AccessPointGUI::validKey(){
	QString res;
	QString entered = ui.txtKey->text();
	try{
		if(entered.size() != 5 && entered.size() != 13)
			throw QString("fail");
		res = entered;
	}
	catch(QString fail){
		QMessageBox::warning(this, tr("Invalid key"), tr("Keys must have a length of 5 or 13. Your key has been tweaked according to this."));
		if(entered.size() < 5)
			res = entered + QString(5 - entered.size(), '0');
		else if(entered.size() < 13)
			res = entered + QString(13 - entered.size(), '0');
		else
			res = entered.left(13);
	}
	return res;
}

==> qtmobilehotspot_0.3.4.tar.gz: qtmobilehotspot-0.3.4/qtMobileHotspot/src/accesspointgui.cpp <==
#include <QtGui/QMainWindow>
#include <QtGui/QMenuBar>
#include <QtGui/QMessageBox>
#include <QtCore/QString>
#include "mobilehotspotconfiguration.h"
#include "accesspointgui.h"


AccessPointGUI::AccessPointGUI(QWidget *parent)
    : QMainWindow(parent)
{
	ui.setupUi(this);
	this->setAttribute(Qt::WA_Maemo5StackedWindow);
}

AccessPointGUI::~AccessPointGUI()
{

}

void AccessPointGUI::closeEvent(QCloseEvent* event){
	// Signal that the GUI is closed
	if(menuBar() != 0)
		menuBar()->clear(); // Solves a bug where menubar in child gui is kept in parent gui
	emit windowClosed();
	event->accept();
}

void AccessPointGUI::setConfiguration(MobileHotspotConfiguration &configuration){
	ui.txtAPName->setText(configuration.hotspotName);
	ui.chkEncryption->setChecked(configuration.encryptionType == configuration.ENCRYPTION_WEP);
	ui.txtKey->setText(configuration.encryptionKey);
	ui.chkWLANDriver->setChecked(configuration.cycleWlanDriver);
}

void AccessPointGUI::configuration(MobileHotspotConfiguration *configuration){
	QString name = ui.txtAPName->text().replace("\\", "").replace("\"", "");
	configuration->hotspotName = name == "" ? "N900 Hotspot" : name;
	configuration->encryptionType = ui.chkEncryption->isChecked() ? configuration->ENCRYPTION_WEP : configuration->ENCRYPTION_NONE;
	configuration->encryptionKey = validKey();
	configuration->cycleWlanDriver = ui.chkWLANDriver->isChecked();
}

QString AccessPointGUI::validKey(){
	QString res;
	QString entered = ui.txtKey->text();
	try{
		if(entered.size() != 5 && entered.size() != 13)
			throw QString("fail");
		res = entered;
	}
	catch(QString fail){
		QMessageBox::warning(this, tr("Invalid key"), tr("Keys must have a length of 5 or 13. Your key has been tweaked according to this."));
		if(entered.size() < 5)
			res = entered + QString(5 - entered.size(), '0');
		else if(entered.size() < 13)
			res = entered + QString(13 - entered.size(), '0');
		else
			res = entered.left(13);
	}
	return res;
}
